<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Point</name>
    <message>
        <location filename="../Point.js" line="+71"/>
        <source>Point Tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Narzędzia punktu</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show point tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wyświetla narzędzia punktu</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Point</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
&amp;Punkt
Środek, &amp;punkt</translatorcomment>
        <translation>&amp;Punkt</translation>
    </message>
</context>
</TS>
